@@ -104,6 +104,13 @@ class FileSystem:
         """Lists all the files in the given directory, relative to it.
 
         :param path:    base directory for search, defaults to current working dir
+        
+        Example:
+
+            ${N} = List Files In Directory   D:/Directory 
+            log to console   ${N} 
+
+        Returns All the files In the specified Directory 
         """
         return self.find_files(Path(path, "*"), include_dirs=False)
 
@@ -111,6 +118,13 @@ class FileSystem:
         """Lists all the directories in the given directory, relative to it.
 
         :param path:    base directory for search, defaults to current working dir
+        
+         Example:
+        
+            ${N} = List Directories In Directory   D:/Folder 
+            log to console   ${N} 
+
+        Returns All the directories in specified directory. 
         """
         return self.find_files(Path(path, "*"), include_files=False)
 
@@ -118,6 +132,11 @@ class FileSystem:
         """Logs all the files in the directory recursively.
 
         :param path:    base directory to start from, defaults to current working dir
+        
+        Example:
+        
+            Log Directory Tree   C:/Folder
+            
         """
         root = Path(path) if path else Path.cwd()
         files = self.find_files(Path(root, "**/*"))
@@ -145,6 +164,12 @@ class FileSystem:
         """Returns True if the given file exists, False if not.
 
         :param path:    path to inspected file
+        
+        Example:
+            
+            Does File Exist   C:/Folder/file.txt
+        
+        
         """
         return bool(self.find_files(path, include_dirs=False))
 
@@ -152,6 +177,14 @@ class FileSystem:
         """Returns True if the file does not exist, False if it does.
 
         :param path:    path to inspected file
+        
+        Example:
+        
+            ${D} = Does File Not Exist   C:/folder/file.ext 
+            log to console   ${D} 
+
+        Returns True if file does not Exist and false if it does exists 
+
         """
         return not self.does_file_exist(path)
 
@@ -159,6 +192,14 @@ class FileSystem:
         """Returns True if the given directory exists, False if not.
 
         :param path:    path to inspected directory
+        
+        Example:
+        
+            ${A} = Does Directory Exist   C: / FolderName 
+            log to console   ${A}
+        
+        Returns True if it Exists And False if it does not 
+        
         """
         return bool(self.find_files(path, include_files=False))
 
@@ -166,6 +207,14 @@ class FileSystem:
         """Returns True if the directory does not exist, False if it does.
 
         :param path:    path to inspected directory
+        
+         Example:
+
+            ${B} = Does Directory Not Exist   C:/FolderName 
+            log to console   ${B} 
+
+        Returns False if it exist and True if it does not
+        
         """
         return not self.does_directory_exist(path)
 
@@ -173,6 +222,14 @@ class FileSystem:
         """Returns True if the given directory has no files or subdirectories.
 
         :param path:    path to inspected directory
+        
+        Example:
+        
+            ${J} = Is Directory Empty   C:/folder/subfolder 
+            log to console   ${J} 
+
+        Returns True if Directory is empty and False if it is not. 
+
         """
         if self.does_directory_not_exist(path):
             raise NotADirectoryError(f"Not a valid directory: {path}")
@@ -183,6 +240,14 @@ class FileSystem:
         """Returns True if the given directory has any files or subdirectories.
 
         :param path:    path to inspected directory
+        
+        Example:
+        
+            ${J} = Is Directory Not Empty   C:/folder/subfolder 
+            log to console   ${J} 
+
+        Returns True if Directory is not empty and False if it is. 
+        
         """
         return not self.is_directory_empty(path)
 
@@ -190,6 +255,13 @@ class FileSystem:
         """Returns True if the given file has no content, i.e. has zero size.
 
         :param path:    path to inspected file
+        
+        Example:
+        
+            ${J} = Is File Empty   C:/folder/subfolder/file.ext 
+            log to console   ${J} 
+
+        Returns True if File is empty and False if it is not. 
         """
         if self.does_file_not_exist(path):
             raise FileNotFoundError(f"Not a valid file: {path}")
@@ -200,6 +272,13 @@ class FileSystem:
         """Returns True if the given file has content, i.e. larger than zero size.
 
         :param path:    path to inspected file
+        
+        Example:
+            
+            ${J} = Is File Not Empty   C:/folder/subfolder/file.ext 
+            log to console   ${J} 
+
+        Returns True if File is not empty and False if it is. 
         """
         return not self.is_file_empty(path)
 
@@ -208,6 +287,13 @@ class FileSystem:
 
         :param path:        path to file to read
         :param encoding:    character encoding of file
+        
+        Example:
+        
+            ${z} = Read File   C:/Folder/File.ext   encoding=utf-8 
+            log to console  $(z) 
+
+        Returns the content of the specified file. 
         """
         with open(path, "r", encoding=encoding) as fd:
             return fd.read()
@@ -217,6 +303,13 @@ class FileSystem:
         Does not attempt to decode the content in any way.
 
         :param path:        path to file to read
+        
+        Example:
+        
+            ${Q} = Read Binary File    C:/Folder/file.ext 
+            log to console    ${Q} 
+
+        Returns the content of specified file 
         """
         with open(path, "rb") as fd:
             return fd.read()
@@ -226,6 +319,12 @@ class FileSystem:
         updates the modification and access times.
 
         :param path:        path to file which is touched
+        
+        Example:
+        
+            Touch File    C:/folder/subfolder/file.ext 
+
+        Creates the file at specified dir if not already exists 
         """
         Path(path).touch()
 
@@ -236,6 +335,11 @@ class FileSystem:
         :param content:     content to write to file (optional)
         :param encoding:    character encoding of written content
         :param overwrite:   replace destination file if it already exists
+        
+        Example:
+        
+            Create File    C:/Folder/file.ext    Content    overwrite=True 
+        
         """
         if not overwrite and Path(path).exists():
             raise FileExistsError(f"Path already exists: {path}")
@@ -250,6 +354,16 @@ class FileSystem:
         :param path:        path to file to write
         :param content:     content to write to file (optional)
         :param overwrite:   replace destination file if it already exists
+        
+        Example:
+        
+            Create Binary File   C:/Folder/test.bin     Content 
+        
+        or
+        
+            Create Binary File	${dir}/example.png	${image content}
+            Create Binary File	${path}
+            
         """
         if not overwrite and Path(path).exists():
             raise FileExistsError(f"Path already exists: {path}")
@@ -264,6 +378,11 @@ class FileSystem:
         :param path:        path to file to append to
         :param content:     content to append
         :param encoding:    character encoding of appended content
+        
+        Example:
+        
+            Append To File   C:/Folder/Test.txt   "AutoSphere"  
+        
         """
         if not Path(path).exists():
             raise FileNotFoundError(f"File does not exist: {path}")
@@ -276,6 +395,10 @@ class FileSystem:
 
         :param path:        path to file to append to
         :param content:     content to append
+        
+        Example:
+        
+            Append To Binary File   C:/Folder/Test.bin   "AutoSphere" 
         """
         if not Path(path).exists():
             raise FileNotFoundError(f"File does not exist: {path}")
@@ -289,6 +412,11 @@ class FileSystem:
         :param path:        path to new directory
         :param parents:     create missing parent directories
         :param exist_ok:    continue without errors if directory already exists
+        
+        Example:
+        
+            Create directory   C:/Folder/Directory 
+            
         """
         Path(path).mkdir(parents=parents, exist_ok=exist_ok)
 
@@ -297,6 +425,12 @@ class FileSystem:
 
         :param path:    path to the file to remove
         :param force:   ignore non-existent files
+        
+        Example:
+        
+            Remove File    C:/Folder/Subfolder/file.ext   force=True 
+
+        Remove the specified file 
         """
         try:
             Path(path).unlink()
@@ -309,6 +443,12 @@ class FileSystem:
 
         :param paths:   paths to files to be removed
         :param force:   ignore non-existent files
+        
+        Example:
+        
+            Remove Files    C:/folder/subfolder/file1.ext      C:/folder/subfolder/file2.ext 
+
+        Remove multiple files 
         """
         # TODO: glob support
         for path in paths:
@@ -319,6 +459,12 @@ class FileSystem:
 
         :param path:        path to directory
         :param recursive:   remove all subdirectories and files
+        
+        Example:
+        
+            Remove Directory    C:/Folder/SubFolder    recursive=True 
+
+        Removes the specified directory and its containing content 
         """
         if recursive:
             shutil.rmtree(str(path))
@@ -329,6 +475,11 @@ class FileSystem:
         """Removes all the files in the given directory.
 
         :param path:    directory to remove files from
+        
+        Example:
+        
+            Empty Directory   C:/Directory 
+            
         """
         # TODO: Should it remove all subdirectories too?
         for item in self.list_files_in_directory(path):
@@ -341,6 +492,13 @@ class FileSystem:
 
         :param source:      path to source file
         :param destination: path to copy destination
+        
+        Example:
+        
+            Copy file    C:/folder/file.txt    C:/folder/subfolder/file.txt
+
+        Copy specified file to new directory. 
+        
         """
         src = Path(source)
         dst = Path(destination)
@@ -356,6 +514,13 @@ class FileSystem:
 
         :param sources:     list of source files
         :param destination: path to destination folder
+        
+        Example:
+        
+            Copy file    C:/folder/file.txt  C:/folder/file2.txt   C:/folder/subfolder
+
+        Copy specified files to new directory. 
+        
         """
         # TODO: glob support
         dst_dir = Path(destination)
@@ -373,6 +538,11 @@ class FileSystem:
 
         :param source:      path to source directory
         :param destination: path to copy destination
+        
+        Example:
+             
+            Copy Directory   C:/Folder/Test    D:/Folder 
+        
         """
         src = Path(source)
         dst = Path(destination)
@@ -391,6 +561,12 @@ class FileSystem:
         :param source:      source file path for moving
         :param destination: path to move to
         :param overwrite:   replace destination file if it already exists
+        
+        Example:
+        
+            Move file    C:/folder/file.txt    C:/folder/subfolder/file.txt
+
+        Move specified file to new directory. 
         """
         src = Path(source)
         dst = Path(destination)
@@ -409,6 +585,12 @@ class FileSystem:
         :param sources:     list of files to move
         :param destination: path to move destination
         :param overwrite:   replace destination files if they already exist
+        
+        Example:
+        
+            Move file    C:/folder/file1.txt  C:/folder/file2.txt    C:/folder/subfolder
+
+        Move specified file to new directory. 
         """
         dst_dir = Path(destination)
 
@@ -425,6 +607,18 @@ class FileSystem:
         :param source:      source directory path for moving
         :param destination: path to move to
         :param overwrite:   replace destination directory if it already exists
+        
+        Example:
+        
+            Move directory     C:/Folder/Directory    C:/Folder 
+
+
+        Move the source Directory to Destination folder. 
+        
+        Note:
+            
+            Works fine with library OperatingSystem
+            
         """
         src = Path(source)
         dst = Path(destination)
@@ -441,6 +635,11 @@ class FileSystem:
 
         :param path:        path to file to rename
         :param extension:   new extension, e.g. .xlsx
+        
+        Example: 
+
+            Change File Extension  C:/Folder/File.ext  .ext (new extension) 
+
         """
         dst = Path(path).with_suffix(extension)
         self.move_file(path, dst)
@@ -449,6 +648,15 @@ class FileSystem:
         """Joins multiple parts of a path together.
 
         :param parts:  Components of the path, e.g. dir, subdir, filename.ext
+        
+        Examples:
+
+            ${path} =	Join Path	my	path		
+            ${p2} =	Join Path	my/	path/		
+            ${p3} =	Join Path	my	path	my	file.txt
+            ${p4} =	Join Path	my	/path		
+            ${p5} =	Join Path	/my/path/	..	path2
+            
         """
         parts = [str(part) for part in parts]
         return str(Path(*parts))
@@ -458,6 +666,13 @@ class FileSystem:
 
         :param path:    path that will be resolved
         :return:        absolute path to file
+        
+        ${Path} = Absolute Path  FileName.ext 
+
+        Example:
+        
+            Returns : C:/Folder/FileName.ext (Return the path of File) 
+
         """
         return str(Path(path).resolve())
 
@@ -466,6 +681,21 @@ class FileSystem:
 
         :param path:    path that will be normalized
         :return:        path to file
+        
+        Examples:
+
+            ${path1} =	Normalize Path	abc/
+            ${path2} =	Normalize Path	abc/../def
+            ${path3} =	Normalize Path	abc/./def//ghi
+            ${path4} =	Normalize Path	~robot/stuff
+            
+        Output:
+        
+            ${path1} = 'abc'
+            ${path2} = 'def'
+            ${path3} = 'abc/def/ghi'
+            ${path4} = '/home/robot/stuff'
+
         """
         return str(os.path.normpath(Path(path)))
 
@@ -473,6 +703,13 @@ class FileSystem:
         """Returns only the filename portion of a path.
 
         :param path:    path to file
+        
+        Example:
+        
+            ${H} = Get File Name   C:/folder/file.ext 
+            log to console   ${H} 
+
+        Returns just the name of specified file 
         """
         return str(Path(path).name)
 
@@ -480,6 +717,11 @@ class FileSystem:
         """Returns the suffix for the file.
 
         :param path:    path to file
+        
+        Example:
+        
+            Get File Extension    C:/Folder/File1
+        
         """
         return Path(path).suffix
 
@@ -487,6 +729,11 @@ class FileSystem:
         """Returns the modified time in seconds.
 
         :param path:    path to file to inspect
+        
+        Example:
+        
+            Get File Modified Date    C:/Folder/File1
+            
         """
         # TODO: Convert to proper date
         return Path(path).stat().st_mtime
@@ -496,6 +743,11 @@ class FileSystem:
         Note: Linux sets this whenever file metadata changes
 
         :param path:    path to file to inspect
+        
+        Example:
+        
+            Get File Creation Date    C:/Folder/movecopy_multi-1.txt
+            
         """
         # TODO: Convert to proper date
         return Path(path).stat().st_ctime
@@ -504,6 +756,13 @@ class FileSystem:
         """Returns the file size in bytes.
 
         :param path:    path to file to inspect
+        
+        Example:
+        
+            ${I} = Get File Size   C:/folder/file.ext 
+            Log to console   ${I} 
+
+        Returns Size of the specified file in bytes. 
         """
         # TODO: Convert to human-friendly?
         return Path(path).stat().st_size
@@ -538,6 +797,11 @@ class FileSystem:
 
         :param path:    path to poll
         :param timeout: time in seconds until keyword fails
+        
+        Example:
+        
+            Wait until modified    process.log
+            
         """
         now = time.time()
         if not self._wait_file(path, lambda p: p.stat().st_mtime >= now, timeout):
@@ -567,6 +831,13 @@ class FileSystem:
         :param path:    path to file to inspect
         :param keyword: Robot Framework keyword to execute
         :param args:    arguments to keyword
+        
+        Example:
+
+            FOR    ${file}  IN  @{FILES}
+                Run keyword if    ${file.size} > 10**8    Remove file    ${file}
+            END
+
         """
         if self.does_file_exist(path):
             return BuiltIn().run_keyword(keyword, *args)
